<template>
    <view class="c-nav-bar">
        <AtNavBar
            :title="title"
            :leftIconType="iconType"
            :onClickLeftIcon="evt => onGoBack()"
            :rightFirstIconType="dropNav ? 'bullet-list' : ''"
            :onClickRgIconSt="evt => onDropMenu()"
        />
        <view
            class="c-nav-bar-right"
            v-if="!dropNav"
        >
            <slot />
        </view>
        <view
            class="c-nav-bar-drop"
            v-show="dropShow"
        >
            <view class="inner">
                <view class="arrow"></view>
                <view class="box">
                    <view
                        class="c-nav-bar-drop-item item"
                        v-for="(nav,index) in dropNav"
                        :key="index"
                        @tap="evt=>onGoNav(nav)"
                    >{{nav.title}}</view>
                </view>
            </view>
        </view>
    </view>
</template>

<script>
import Taro from '@tarojs/taro';
import { AtNavBar } from 'taro-ui-vue';
import './cNavBar.scss';

export default {
    name: 'CNavBar',
    components: {
        AtNavBar,
    },
    props: {
        // H5页面导航标题
        title: String,
        // H5页面导航左侧图标
        iconType: {
            type: String,
            default: 'chevron-left',
        },
        // H5页面导航左侧图点击事件
        onClickIcon: Function,
        // H5页面导航右侧下拉菜单配置
        dropNav: Array,
    },
    data() {
        return {
            dropShow: false,
            dropTimer: -1,
            dropActive: false,
        };
    },
    methods: {
        onGoBack() {
            if (this.onClickIcon) {
                const needBack = this.onClickIcon();
                // 返回 true 时继续跳回上一页
                if (needBack) {
                    Taro.navigateBack();
                }
            } else {
                Taro.navigateBack();
            }
        },
        onGoNav(nav) {
            if (!nav.url) {
                return;
            }
            this.dropShow = false;
            setTimeout(() => {
                Taro.navigateTo({ url: nav.url });
            }, 0);
        },
        onDropMenu() {
            this.dropShow = !this.dropShow;
            this.dropActive = true;
            clearTimeout(this.dropTimer);
            this.dropTimer = setTimeout(() => {
                this.dropActive = false;
            }, 500);
        },
        outCloseMenu(evt) {
            setTimeout(() => {
                // 未打开时，忽略
                if (!this.dropShow) {
                    return;
                }
                // 刚刚打开的一段时间内，忽略
                if (this.dropActive) {
                    return;
                }
                // 点击了菜单项，忽略
                const className = evt.target.className;
                if (
                    className.indexOf('c-nav-bar-drop-item') >= 0 ||
                    className.indexOf('at-nav-bar__container') >= 0
                ) {
                    return;
                }
                // 执行关闭
                this.dropShow = false;
            }, 0);
        },
    },
    mounted() {
        Taro.eventCenter.on('pageTouchstart', this.outCloseMenu);
        Taro.eventCenter.on('pageClick', this.outCloseMenu);
    },
    beforeDestroy() {
        Taro.eventCenter.off('pageTouchstart', this.outCloseMenu);
        Taro.eventCenter.off('pageClick', this.outCloseMenu);
    },
};
</script>